var searchData=
[
  ['v4l2_5fdevice_2eh_0',['v4l2_device.h',['../v4l2__device_8h.html',1,'']]],
  ['v4l2_5fpixelformat_2eh_1',['v4l2_pixelformat.h',['../v4l2__pixelformat_8h.html',1,'']]],
  ['v4l2_5fsubdevice_2eh_2',['v4l2_subdevice.h',['../v4l2__subdevice_8h.html',1,'']]],
  ['v4l2_5fvideodevice_2eh_3',['v4l2_videodevice.h',['../v4l2__videodevice_8h.html',1,'']]],
  ['v4l2buffercache_4',['V4L2BufferCache',['../classlibcamera_1_1V4L2BufferCache.html',1,'libcamera::V4L2BufferCache'],['../classlibcamera_1_1V4L2BufferCache.html#a2e85353e7d8aaeb616be5dd642830401',1,'libcamera::V4L2BufferCache::V4L2BufferCache(unsigned int numEntries)'],['../classlibcamera_1_1V4L2BufferCache.html#abf2d3fdf1877c5db0ea73a4ccc17ed46',1,'libcamera::V4L2BufferCache::V4L2BufferCache(const std::vector&lt; std::unique_ptr&lt; FrameBuffer &gt; &gt; &amp;buffers)']]],
  ['v4l2capability_5',['V4L2Capability',['../structlibcamera_1_1V4L2Capability.html',1,'libcamera']]],
  ['v4l2device_6',['V4L2Device',['../classlibcamera_1_1V4L2Device.html',1,'libcamera::V4L2Device'],['../classlibcamera_1_1V4L2Device.html#af2c3423ffe8a3333ea7c82018b49844d',1,'libcamera::V4L2Device::V4L2Device()']]],
  ['v4l2deviceformat_7',['V4L2DeviceFormat',['../classlibcamera_1_1V4L2DeviceFormat.html',1,'libcamera']]],
  ['v4l2formats_8',['v4l2Formats',['../classlibcamera_1_1PixelFormatInfo.html#af7cfa74f77aeb4100c45ce24ec0ade70',1,'libcamera::PixelFormatInfo']]],
  ['v4l2m2mconverter_9',['V4L2M2MConverter',['../classlibcamera_1_1V4L2M2MConverter.html',1,'libcamera::V4L2M2MConverter'],['../classlibcamera_1_1V4L2M2MConverter.html#a29aeac44dbed3e1c76d4daad84038dac',1,'libcamera::V4L2M2MConverter::V4L2M2MConverter()']]],
  ['v4l2m2mdevice_10',['V4L2M2MDevice',['../classlibcamera_1_1V4L2M2MDevice.html',1,'libcamera::V4L2M2MDevice'],['../classlibcamera_1_1V4L2M2MDevice.html#aada8b048cfaaefb7da7347e101dfff7f',1,'libcamera::V4L2M2MDevice::V4L2M2MDevice()']]],
  ['v4l2pixelformat_11',['V4L2PixelFormat',['../classlibcamera_1_1V4L2PixelFormat.html',1,'libcamera::V4L2PixelFormat'],['../classlibcamera_1_1V4L2PixelFormat.html#ac38e458d9f1afd50a057a96c4d2a8132',1,'libcamera::V4L2PixelFormat::V4L2PixelFormat()'],['../classlibcamera_1_1V4L2PixelFormat.html#a6efc742cb5c93d7ac1c67f87b810b56b',1,'libcamera::V4L2PixelFormat::V4L2PixelFormat(uint32_t fourcc)']]],
  ['v4l2subdevice_12',['V4L2Subdevice',['../classlibcamera_1_1V4L2Subdevice.html',1,'libcamera::V4L2Subdevice'],['../classlibcamera_1_1V4L2Subdevice.html#aded4791bb9d9a977f33417b19590d1af',1,'libcamera::V4L2Subdevice::V4L2Subdevice()'],['../classlibcamera_1_1MediaEntity.html#ab75d46f7f7ee3270b3cffbb0e821c7b0a6225cd504cb3e7475e63ab83fed66a8d',1,'libcamera::MediaEntity::V4L2Subdevice']]],
  ['v4l2subdevicecapability_13',['V4L2SubdeviceCapability',['../structlibcamera_1_1V4L2SubdeviceCapability.html',1,'libcamera']]],
  ['v4l2subdeviceformat_14',['V4L2SubdeviceFormat',['../structlibcamera_1_1V4L2SubdeviceFormat.html',1,'libcamera']]],
  ['v4l2videodevice_15',['V4L2VideoDevice',['../classlibcamera_1_1V4L2VideoDevice.html',1,'libcamera::V4L2VideoDevice'],['../classlibcamera_1_1V4L2VideoDevice.html#a612aca15d344aa5c59f9f90d4cb09e57',1,'libcamera::V4L2VideoDevice::V4L2VideoDevice(const std::string &amp;deviceNode)'],['../classlibcamera_1_1V4L2VideoDevice.html#a78fd4cc6f5d062c2392715ae72519377',1,'libcamera::V4L2VideoDevice::V4L2VideoDevice(const MediaEntity *entity)'],['../classlibcamera_1_1MediaEntity.html#ab75d46f7f7ee3270b3cffbb0e821c7b0ae388b4d0db571ad8179ff34593372dea',1,'libcamera::MediaEntity::V4L2VideoDevice']]],
  ['valid_16',['Valid',['../classlibcamera_1_1CameraConfiguration.html#a64163f21db2fe1ce0a6af5a6f6847744ab97a3ad92b8fc0ad1efe74927e26e64a',1,'libcamera::CameraConfiguration']]],
  ['valid_5f_17',['valid_',['../classlibcamera_1_1IPAProxy.html#afb8f81b8f6955191147b8a9f13ec3c1a',1,'libcamera::IPAProxy']]],
  ['validate_18',['validate',['../classlibcamera_1_1CameraConfiguration.html#aae311c7b13dacce196b6c82a1b67bba9',1,'libcamera::CameraConfiguration::validate()'],['../classlibcamera_1_1CameraControlValidator.html#a71b33785a52fcdb71b31bc2286ea412d',1,'libcamera::CameraControlValidator::validate()'],['../classlibcamera_1_1ControlValidator.html#a30f2d3d577428bcd03614f441506a79d',1,'libcamera::ControlValidator::validate()']]],
  ['validatecolorspaces_19',['validateColorSpaces',['../classlibcamera_1_1CameraConfiguration.html#a197791527afd705483a0b6236e32c6b7',1,'libcamera::CameraConfiguration']]],
  ['validateoutput_20',['validateOutput',['../classlibcamera_1_1Converter.html#aff773eb476c5d9941734e2ce21fcfd13',1,'libcamera::Converter::validateOutput()'],['../classlibcamera_1_1V4L2M2MConverter.html#ac8a7bc36b0aac28b810c45929abcd522',1,'libcamera::V4L2M2MConverter::validateOutput()']]],
  ['validator_21',['validator',['../classlibcamera_1_1Camera_1_1Private.html#af42d5796d0bc8e36ff0cd5f0e0eb7443',1,'libcamera::Camera::Private']]],
  ['values_22',['values',['../classlibcamera_1_1ControlInfo.html#a1ce70ac404f45eaf9bb0386918aaedca',1,'libcamera::ControlInfo']]],
  ['vblankdelay_23',['vblankDelay',['../structlibcamera_1_1CameraSensorProperties_1_1SensorDelays.html#a9ca4dfefbc344433764e2bc033b4ad48',1,'libcamera::CameraSensorProperties::SensorDelays']]],
  ['vector_24',['Vector',['../classlibcamera_1_1Vector.html',1,'libcamera::Vector&lt; T, Rows &gt;'],['../classlibcamera_1_1Vector.html#a98073779cde78cde03da4f575fc56257',1,'libcamera::Vector::Vector()=default'],['../classlibcamera_1_1Vector.html#a607fb9af7a28b1427d6d4443a52a07c7',1,'libcamera::Vector::Vector(T scalar)'],['../classlibcamera_1_1Vector.html#a2f8ddd4a967c819967ca20ded11b460c',1,'libcamera::Vector::Vector(const std::array&lt; T, Rows &gt; &amp;data)']]],
  ['vector_2eh_25',['vector.h',['../vector_8h.html',1,'']]],
  ['vector_3c_20double_2c_202_20_3e_26',['Vector&lt; double, 2 &gt;',['../classlibcamera_1_1Vector.html',1,'libcamera']]],
  ['vector_3c_20t_2c_203_20_3e_27',['Vector&lt; T, 3 &gt;',['../classlibcamera_1_1Vector.html',1,'libcamera']]],
  ['vector_3c_20t_2c_203_20_3e_3c_20double_20_3e_28',['Vector&lt; T, 3 &gt;&lt; double &gt;',['../classlibcamera_1_1Vector.html',1,'libcamera']]],
  ['vendor_29',['vendor',['../classlibcamera_1_1ControlId.html#aba34f493d8313c60930c9d9cce61922c',1,'libcamera::ControlId']]],
  ['verify_30',['verify',['../classlibcamera_1_1PubKey.html#a959683b12bed8b7ec178c8b0b72fe6c5',1,'libcamera::PubKey']]],
  ['version_31',['version',['../structlibcamera_1_1ipa__controls__header.html#a3a765c275ff9ca1fbeb6c30710991735',1,'libcamera::ipa_controls_header::version'],['../classlibcamera_1_1CameraManager.html#a7a9c0aefeac0ff1e3a42da3072ab0a97',1,'libcamera::CameraManager::version()'],['../classlibcamera_1_1MediaDevice.html#af335184ee6174ea68747d32955d6f9c8',1,'libcamera::MediaDevice::version()']]],
  ['verticalsubsampling_32',['verticalSubSampling',['../structlibcamera_1_1PixelFormatInfo_1_1Plane.html#a718acb445ae5af9825489f728c78db9c',1,'libcamera::PixelFormatInfo::Plane']]],
  ['vflip_33',['VFlip',['../namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571a0b5d83f7ecb707aee4151b6575ca5af7',1,'libcamera']]],
  ['videorecording_34',['VideoRecording',['../namespacelibcamera.html#a295d1f5e7828d95c0b0aabc0a8baac03ae1ff48054403b149f903eb40e16ec86e',1,'libcamera']]],
  ['viewfinder_35',['Viewfinder',['../namespacelibcamera.html#a295d1f5e7828d95c0b0aabc0a8baac03a30b5987e4c03f83a7e1909e4f72eefd4',1,'libcamera']]],
  ['vstep_36',['vStep',['../classlibcamera_1_1SizeRange.html#ae00aab56b782a1a098f6fe1dcc2d0d8a',1,'libcamera::SizeRange']]]
];
